@@ -17,6 +17,8 @@ if sys.platform.startswith("darwin"):
         lib_name += "_arm64"
 else:
     lib_ext = ".so"
+    if "aarch64" in platform.machine():
+        lib_name += "_aarch64"
 
 lib_path = "".join([path.dirname(__file__), "/libs/", lib_name, lib_ext])
 lib_contrast = ctypes.cdll.LoadLibrary(lib_path)
